@@ -43,17 +43,14 @@
 #' data <- fred_transform(data, codes = c(5, 5, 1), lag = 4)
 #'
 #' # Estimate a BVAR using one lag, default settings and very few draws
-#' x <- bvar(data, lags = 1, n_draw = 1000L, n_burn = 200L, verbose = FALSE)
+#' x <- bvar(data, lags = 1, n_draw = 600L, n_burn = 100L, verbose = FALSE)
 #'
-#' # Calculate and store structural IRFs (via Cholesky decomposition)
-#' irf(x) <- irf(x, identification = TRUE)
+#' # Compute + store IRF with a longer horizon, no identification and thinning
+#' irf(x) <- irf(x, bv_irf(horizon = 24L, identification = FALSE), n_thin = 5L)
 #'
 #' # Update the confidence bands of the IRFs
 #' irf(x, conf_bands = c(0.01, 0.05, 0.1))
 #'
-#' # Compute and store with a longer horizon, no identification and thinning
-#' irf(x) <- irf(x, bv_irf(horizon = 24L, identification = FALSE), n_thin = 10L)
-#'
 #' # Recalculate with sign restrictions provided via the ellipsis
 #' irf(x, sign_restr = matrix(c(1, NA, NA, -1, 1, -1, -1, 1, 1), nrow = 3))
 #'
@@ -209,6 +206,21 @@ fevd.bvar <- function(x, ..., conf_bands, n_thin = 1L) {
 }
 
 
+#' @noRd
+#' @export
+`fevd<-.bvar` <- function(x, value) {
+
+  if(!inherits(x, "bvar")) {stop("Please use a `bvar` object.")}
+  if(!inherits(value, "bvar_fevd")) {
+    stop("Please provide a `bvar_fevd` object to assign.")
+  }
+
+  x[["fevd"]] <- value
+
+  return(x)
+}
+
+
 #' @noRd
 #' @export
 fevd.bvar_irf <- function(x, conf_bands, ...) {
@@ -284,3 +296,8 @@ fevd <- function(x, ...) {UseMethod("fevd", x)}
 fevd.default <- function(x, ...) {
   stop("No methods for class ", paste0(class(x), collapse = " / "), " found.")
 }
+
+
+#' @rdname irf.bvar
+#' @export
+`fevd<-` <- function(x, value) {UseMethod("fevd<-", x)}
